from bluer_sbc.README.designs import (
    cheshmak,
    battery_bus,
    adapter_bus,
    swallow,
    swallow_head,
    bryce,
    nafha,
    shelter,
    template,
    ultrasonic_sensor_tester,
)


docs = (
    battery_bus.docs
    + adapter_bus.docs
    + bryce.docs
    + cheshmak.docs
    + nafha.docs
    + shelter.docs
    + swallow_head.docs
    + swallow.docs
    + ultrasonic_sensor_tester.docs
    + template.docs
)
